function [itest,manpresstest,horsestest,RPMtest]=rpmline2(i,manpress,horses,RPMvalue)
% function [itest,manpresstest,horsestest,RPMtest]=rpmline2(i,manpress,horses,RPMvalue)
% i=1, 2, 3, 4, or 5
% itest is the array giving the element numbers of the ith rpm line in 
% horsepower vs manifold pressure.
% manpress is a vector of manifold pressure values.
% horses is a vector of horsepower data.
% RPMvalue is a 1x5 vector of different RPM levels. Each fourteen data points
% corresponds to a new RPM value. There are 5 rpm values.
% .
istart=(i-1)*14+1;
iend=istart+13;
itest=istart:iend;
manpresstest=manpress(itest);
horsestest=horses(itest);
RPMtest=RPMvalue(i);
